"""Array-size annotations for OpenGL.raw.GLE

Automatically generated by the generateraw script, do not edit!
"""
from OpenGL.raw import GLE as raw

from ctypes import *
from OpenGL import platform, arrays
from OpenGL.constant import Constant
from OpenGL.raw.GL import _types as GL_types
GLvoid = GL_types.GLvoid
STRING = c_char_p


gleExtrusion = arrays.setInputArraySizeType(
    arrays.setInputArraySizeType(
        arrays.setInputArraySizeType(
            arrays.setInputArraySizeType(
                arrays.setInputArraySizeType(
                    raw.gleExtrusion,
                    None, # XXX Could not determine size of argument contour for gleExtrusion arrays.GLdoubleArray
                    arrays.GLdoubleArray, 
                    'contour',
                ),
                None, # XXX Could not determine size of argument cont_normal for gleExtrusion arrays.GLdoubleArray
                arrays.GLdoubleArray, 
                'cont_normal',
            ),
            None, # XXX Could not determine size of argument up for gleExtrusion arrays.GLdoubleArray
            arrays.GLdoubleArray, 
            'up',
        ),
        None, # XXX Could not determine size of argument point_array for gleExtrusion arrays.GLdoubleArray
        arrays.GLdoubleArray, 
        'point_array',
    ),
    None, # XXX Could not determine size of argument color_array for gleExtrusion arrays.GLfloatArray
    arrays.GLfloatArray, 
    'color_array',
)

gleHelicoid = arrays.setInputArraySizeType(
    arrays.setInputArraySizeType(
        raw.gleHelicoid,
        None, # XXX Could not determine size of argument startXform for gleHelicoid arrays.GLdoubleArray
        arrays.GLdoubleArray, 
        'startXform',
    ),
    None, # XXX Could not determine size of argument dXformdTheta for gleHelicoid arrays.GLdoubleArray
    arrays.GLdoubleArray, 
    'dXformdTheta',
)

gleLathe = arrays.setInputArraySizeType(
    arrays.setInputArraySizeType(
        arrays.setInputArraySizeType(
            arrays.setInputArraySizeType(
                arrays.setInputArraySizeType(
                    raw.gleLathe,
                    None, # XXX Could not determine size of argument contour for gleLathe arrays.GLdoubleArray
                    arrays.GLdoubleArray, 
                    'contour',
                ),
                None, # XXX Could not determine size of argument cont_normal for gleLathe arrays.GLdoubleArray
                arrays.GLdoubleArray, 
                'cont_normal',
            ),
            None, # XXX Could not determine size of argument up for gleLathe arrays.GLdoubleArray
            arrays.GLdoubleArray, 
            'up',
        ),
        None, # XXX Could not determine size of argument startXform for gleLathe arrays.GLdoubleArray
        arrays.GLdoubleArray, 
        'startXform',
    ),
    None, # XXX Could not determine size of argument dXformdTheta for gleLathe arrays.GLdoubleArray
    arrays.GLdoubleArray, 
    'dXformdTheta',
)

glePolyCone = arrays.setInputArraySizeType(
    arrays.setInputArraySizeType(
        arrays.setInputArraySizeType(
            raw.glePolyCone,
            None, # XXX Could not determine size of argument point_array for glePolyCone arrays.GLdoubleArray
            arrays.GLdoubleArray, 
            'point_array',
        ),
        None, # XXX Could not determine size of argument color_array for glePolyCone arrays.GLfloatArray
        arrays.GLfloatArray, 
        'color_array',
    ),
    None, # XXX Could not determine size of argument radius_array for glePolyCone arrays.GLdoubleArray
    arrays.GLdoubleArray, 
    'radius_array',
)

glePolyCylinder = arrays.setInputArraySizeType(
    arrays.setInputArraySizeType(
        raw.glePolyCylinder,
        None, # XXX Could not determine size of argument point_array for glePolyCylinder arrays.GLdoubleArray
        arrays.GLdoubleArray, 
        'point_array',
    ),
    None, # XXX Could not determine size of argument color_array for glePolyCylinder arrays.GLfloatArray
    arrays.GLfloatArray, 
    'color_array',
)

gleScrew = arrays.setInputArraySizeType(
    arrays.setInputArraySizeType(
        arrays.setInputArraySizeType(
            raw.gleScrew,
            None, # XXX Could not determine size of argument contour for gleScrew arrays.GLdoubleArray
            arrays.GLdoubleArray, 
            'contour',
        ),
        None, # XXX Could not determine size of argument cont_normal for gleScrew arrays.GLdoubleArray
        arrays.GLdoubleArray, 
        'cont_normal',
    ),
    None, # XXX Could not determine size of argument up for gleScrew arrays.GLdoubleArray
    arrays.GLdoubleArray, 
    'up',
)

gleSpiral = arrays.setInputArraySizeType(
    arrays.setInputArraySizeType(
        arrays.setInputArraySizeType(
            arrays.setInputArraySizeType(
                arrays.setInputArraySizeType(
                    raw.gleSpiral,
                    None, # XXX Could not determine size of argument contour for gleSpiral arrays.GLdoubleArray
                    arrays.GLdoubleArray, 
                    'contour',
                ),
                None, # XXX Could not determine size of argument cont_normal for gleSpiral arrays.GLdoubleArray
                arrays.GLdoubleArray, 
                'cont_normal',
            ),
            None, # XXX Could not determine size of argument up for gleSpiral arrays.GLdoubleArray
            arrays.GLdoubleArray, 
            'up',
        ),
        None, # XXX Could not determine size of argument startXform for gleSpiral arrays.GLdoubleArray
        arrays.GLdoubleArray, 
        'startXform',
    ),
    None, # XXX Could not determine size of argument dXformdTheta for gleSpiral arrays.GLdoubleArray
    arrays.GLdoubleArray, 
    'dXformdTheta',
)

gleSuperExtrusion = arrays.setInputArraySizeType(
    arrays.setInputArraySizeType(
        arrays.setInputArraySizeType(
            arrays.setInputArraySizeType(
                arrays.setInputArraySizeType(
                    arrays.setInputArraySizeType(
                        raw.gleSuperExtrusion,
                        None, # XXX Could not determine size of argument contour for gleSuperExtrusion arrays.GLdoubleArray
                        arrays.GLdoubleArray, 
                        'contour',
                    ),
                    None, # XXX Could not determine size of argument cont_normal for gleSuperExtrusion arrays.GLdoubleArray
                    arrays.GLdoubleArray, 
                    'cont_normal',
                ),
                None, # XXX Could not determine size of argument up for gleSuperExtrusion arrays.GLdoubleArray
                arrays.GLdoubleArray, 
                'up',
            ),
            None, # XXX Could not determine size of argument point_array for gleSuperExtrusion arrays.GLdoubleArray
            arrays.GLdoubleArray, 
            'point_array',
        ),
        None, # XXX Could not determine size of argument color_array for gleSuperExtrusion arrays.GLfloatArray
        arrays.GLfloatArray, 
        'color_array',
    ),
    None, # XXX Could not determine size of argument xform_array for gleSuperExtrusion arrays.GLdoubleArray
    arrays.GLdoubleArray, 
    'xform_array',
)

gleToroid = arrays.setInputArraySizeType(
    arrays.setInputArraySizeType(
        raw.gleToroid,
        None, # XXX Could not determine size of argument startXform for gleToroid arrays.GLdoubleArray
        arrays.GLdoubleArray, 
        'startXform',
    ),
    None, # XXX Could not determine size of argument dXformdTheta for gleToroid arrays.GLdoubleArray
    arrays.GLdoubleArray, 
    'dXformdTheta',
)

gleTwistExtrusion = arrays.setInputArraySizeType(
    arrays.setInputArraySizeType(
        arrays.setInputArraySizeType(
            arrays.setInputArraySizeType(
                arrays.setInputArraySizeType(
                    arrays.setInputArraySizeType(
                        raw.gleTwistExtrusion,
                        None, # XXX Could not determine size of argument contour for gleTwistExtrusion arrays.GLdoubleArray
                        arrays.GLdoubleArray, 
                        'contour',
                    ),
                    None, # XXX Could not determine size of argument cont_normal for gleTwistExtrusion arrays.GLdoubleArray
                    arrays.GLdoubleArray, 
                    'cont_normal',
                ),
                None, # XXX Could not determine size of argument up for gleTwistExtrusion arrays.GLdoubleArray
                arrays.GLdoubleArray, 
                'up',
            ),
            None, # XXX Could not determine size of argument point_array for gleTwistExtrusion arrays.GLdoubleArray
            arrays.GLdoubleArray, 
            'point_array',
        ),
        None, # XXX Could not determine size of argument color_array for gleTwistExtrusion arrays.GLfloatArray
        arrays.GLfloatArray, 
        'color_array',
    ),
    None, # XXX Could not determine size of argument twist_array for gleTwistExtrusion arrays.GLdoubleArray
    arrays.GLdoubleArray, 
    'twist_array',
)

rot_about_axis = arrays.setInputArraySizeType(
    raw.rot_about_axis,
    None, # XXX Could not determine size of argument axis for rot_about_axis arrays.GLdoubleArray
    arrays.GLdoubleArray, 
    'axis',
)

rot_axis = arrays.setInputArraySizeType(
    raw.rot_axis,
    None, # XXX Could not determine size of argument axis for rot_axis arrays.GLdoubleArray
    arrays.GLdoubleArray, 
    'axis',
)

rot_omega = arrays.setInputArraySizeType(
    raw.rot_omega,
    None, # XXX Could not determine size of argument axis for rot_omega arrays.GLdoubleArray
    arrays.GLdoubleArray, 
    'axis',
)

urot_about_axis = arrays.setInputArraySizeType(
    arrays.setInputArraySizeType(
        raw.urot_about_axis,
        None, # XXX Could not determine size of argument m for urot_about_axis arrays.GLdoubleArray
        arrays.GLdoubleArray, 
        'm',
    ),
    None, # XXX Could not determine size of argument axis for urot_about_axis arrays.GLdoubleArray
    arrays.GLdoubleArray, 
    'axis',
)

urot_axis = arrays.setInputArraySizeType(
    arrays.setInputArraySizeType(
        raw.urot_axis,
        None, # XXX Could not determine size of argument m for urot_axis arrays.GLdoubleArray
        arrays.GLdoubleArray, 
        'm',
    ),
    None, # XXX Could not determine size of argument axis for urot_axis arrays.GLdoubleArray
    arrays.GLdoubleArray, 
    'axis',
)

urot_omega = arrays.setInputArraySizeType(
    arrays.setInputArraySizeType(
        raw.urot_omega,
        None, # XXX Could not determine size of argument m for urot_omega arrays.GLdoubleArray
        arrays.GLdoubleArray, 
        'm',
    ),
    None, # XXX Could not determine size of argument axis for urot_omega arrays.GLdoubleArray
    arrays.GLdoubleArray, 
    'axis',
)

urot_prince = arrays.setInputArraySizeType(
    raw.urot_prince,
    None, # XXX Could not determine size of argument m for urot_prince arrays.GLdoubleArray
    arrays.GLdoubleArray, 
    'm',
)

uview_direction = arrays.setInputArraySizeType(
    arrays.setInputArraySizeType(
        arrays.setInputArraySizeType(
            raw.uview_direction,
            None, # XXX Could not determine size of argument m for uview_direction arrays.GLdoubleArray
            arrays.GLdoubleArray, 
            'm',
        ),
        None, # XXX Could not determine size of argument v21 for uview_direction arrays.GLdoubleArray
        arrays.GLdoubleArray, 
        'v21',
    ),
    None, # XXX Could not determine size of argument up for uview_direction arrays.GLdoubleArray
    arrays.GLdoubleArray, 
    'up',
)

uviewpoint = arrays.setInputArraySizeType(
    arrays.setInputArraySizeType(
        arrays.setInputArraySizeType(
            arrays.setInputArraySizeType(
                raw.uviewpoint,
                None, # XXX Could not determine size of argument m for uviewpoint arrays.GLdoubleArray
                arrays.GLdoubleArray, 
                'm',
            ),
            None, # XXX Could not determine size of argument v1 for uviewpoint arrays.GLdoubleArray
            arrays.GLdoubleArray, 
            'v1',
        ),
        None, # XXX Could not determine size of argument v2 for uviewpoint arrays.GLdoubleArray
        arrays.GLdoubleArray, 
        'v2',
    ),
    None, # XXX Could not determine size of argument up for uviewpoint arrays.GLdoubleArray
    arrays.GLdoubleArray, 
    'up',
)

__all__ = [
    'gleExtrusion',
    'gleHelicoid',
    'gleLathe',
    'glePolyCone',
    'glePolyCylinder',
    'gleScrew',
    'gleSpiral',
    'gleSuperExtrusion',
    'gleToroid',
    'gleTwistExtrusion',
    'rot_about_axis',
    'rot_axis',
    'rot_omega',
    'urot_about_axis',
    'urot_axis',
    'urot_omega',
    'urot_prince',
    'uview_direction',
    'uviewpoint'
]
