"""C-style "raw" API for low-level ctypes-specific access to OpenGL

This sub-package is autogenerated using a customised version
of the ctypes codegenerator package (see src/openglgenerator.py and
src/generateraw.py).
"""