'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_NV_pixel_data_range'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_NV_pixel_data_range',error_checker=_errors._error_checker)
GL_READ_PIXEL_DATA_RANGE_LENGTH_NV=_C('GL_READ_PIXEL_DATA_RANGE_LENGTH_NV',0x887B)
GL_READ_PIXEL_DATA_RANGE_NV=_C('GL_READ_PIXEL_DATA_RANGE_NV',0x8879)
GL_READ_PIXEL_DATA_RANGE_POINTER_NV=_C('GL_READ_PIXEL_DATA_RANGE_POINTER_NV',0x887D)
GL_WRITE_PIXEL_DATA_RANGE_LENGTH_NV=_C('GL_WRITE_PIXEL_DATA_RANGE_LENGTH_NV',0x887A)
GL_WRITE_PIXEL_DATA_RANGE_NV=_C('GL_WRITE_PIXEL_DATA_RANGE_NV',0x8878)
GL_WRITE_PIXEL_DATA_RANGE_POINTER_NV=_C('GL_WRITE_PIXEL_DATA_RANGE_POINTER_NV',0x887C)
@_f
@_p.types(None,_cs.GLenum)
def glFlushPixelDataRangeNV(target):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLsizei,ctypes.c_void_p)
def glPixelDataRangeNV(target,length,pointer):pass
