'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES2 import _types as _cs
# End users want this...
from OpenGL.raw.GLES2._types import *
from OpenGL.raw.GLES2 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES2_EXT_multiview_draw_buffers'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES2,'GLES2_EXT_multiview_draw_buffers',error_checker=_errors._error_checker)
GL_COLOR_ATTACHMENT_EXT=_C('GL_COLOR_ATTACHMENT_EXT',0x90F0)
GL_DRAW_BUFFER_EXT=_C('GL_DRAW_BUFFER_EXT',0x0C01)
GL_MAX_MULTIVIEW_BUFFERS_EXT=_C('GL_MAX_MULTIVIEW_BUFFERS_EXT',0x90F2)
GL_MULTIVIEW_EXT=_C('GL_MULTIVIEW_EXT',0x90F1)
GL_READ_BUFFER_EXT=_C('GL_READ_BUFFER_EXT',0x0C02)
@_f
@_p.types(None,_cs.GLint,arrays.GLuintArray,arrays.GLintArray)
def glDrawBuffersIndexedEXT(n,location,indices):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,arrays.GLintArray)
def glGetIntegeri_vEXT(target,index,data):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint)
def glReadBufferIndexedEXT(src,index):pass
