'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_VERSION_GL_1_4'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_VERSION_GL_1_4',error_checker=_errors._error_checker)
GL_BLEND_DST_ALPHA=_C('GL_BLEND_DST_ALPHA',0x80CA)
GL_BLEND_DST_RGB=_C('GL_BLEND_DST_RGB',0x80C8)
GL_BLEND_SRC_ALPHA=_C('GL_BLEND_SRC_ALPHA',0x80CB)
GL_BLEND_SRC_RGB=_C('GL_BLEND_SRC_RGB',0x80C9)
GL_COLOR_SUM=_C('GL_COLOR_SUM',0x8458)
GL_COMPARE_R_TO_TEXTURE=_C('GL_COMPARE_R_TO_TEXTURE',0x884E)
GL_CONSTANT_ALPHA=_C('GL_CONSTANT_ALPHA',0x8003)
GL_CONSTANT_COLOR=_C('GL_CONSTANT_COLOR',0x8001)
GL_CURRENT_FOG_COORDINATE=_C('GL_CURRENT_FOG_COORDINATE',0x8453)
GL_CURRENT_SECONDARY_COLOR=_C('GL_CURRENT_SECONDARY_COLOR',0x8459)
GL_DECR_WRAP=_C('GL_DECR_WRAP',0x8508)
GL_DEPTH_COMPONENT16=_C('GL_DEPTH_COMPONENT16',0x81A5)
GL_DEPTH_COMPONENT24=_C('GL_DEPTH_COMPONENT24',0x81A6)
GL_DEPTH_COMPONENT32=_C('GL_DEPTH_COMPONENT32',0x81A7)
GL_DEPTH_TEXTURE_MODE=_C('GL_DEPTH_TEXTURE_MODE',0x884B)
GL_FOG_COORDINATE=_C('GL_FOG_COORDINATE',0x8451)
GL_FOG_COORDINATE_ARRAY=_C('GL_FOG_COORDINATE_ARRAY',0x8457)
GL_FOG_COORDINATE_ARRAY_POINTER=_C('GL_FOG_COORDINATE_ARRAY_POINTER',0x8456)
GL_FOG_COORDINATE_ARRAY_STRIDE=_C('GL_FOG_COORDINATE_ARRAY_STRIDE',0x8455)
GL_FOG_COORDINATE_ARRAY_TYPE=_C('GL_FOG_COORDINATE_ARRAY_TYPE',0x8454)
GL_FOG_COORDINATE_SOURCE=_C('GL_FOG_COORDINATE_SOURCE',0x8450)
GL_FRAGMENT_DEPTH=_C('GL_FRAGMENT_DEPTH',0x8452)
GL_FUNC_ADD=_C('GL_FUNC_ADD',0x8006)
GL_FUNC_REVERSE_SUBTRACT=_C('GL_FUNC_REVERSE_SUBTRACT',0x800B)
GL_FUNC_SUBTRACT=_C('GL_FUNC_SUBTRACT',0x800A)
GL_GENERATE_MIPMAP=_C('GL_GENERATE_MIPMAP',0x8191)
GL_GENERATE_MIPMAP_HINT=_C('GL_GENERATE_MIPMAP_HINT',0x8192)
GL_INCR_WRAP=_C('GL_INCR_WRAP',0x8507)
GL_MAX=_C('GL_MAX',0x8008)
GL_MAX_TEXTURE_LOD_BIAS=_C('GL_MAX_TEXTURE_LOD_BIAS',0x84FD)
GL_MIN=_C('GL_MIN',0x8007)
GL_MIRRORED_REPEAT=_C('GL_MIRRORED_REPEAT',0x8370)
GL_ONE_MINUS_CONSTANT_ALPHA=_C('GL_ONE_MINUS_CONSTANT_ALPHA',0x8004)
GL_ONE_MINUS_CONSTANT_COLOR=_C('GL_ONE_MINUS_CONSTANT_COLOR',0x8002)
GL_POINT_DISTANCE_ATTENUATION=_C('GL_POINT_DISTANCE_ATTENUATION',0x8129)
GL_POINT_FADE_THRESHOLD_SIZE=_C('GL_POINT_FADE_THRESHOLD_SIZE',0x8128)
GL_POINT_SIZE_MAX=_C('GL_POINT_SIZE_MAX',0x8127)
GL_POINT_SIZE_MIN=_C('GL_POINT_SIZE_MIN',0x8126)
GL_SECONDARY_COLOR_ARRAY=_C('GL_SECONDARY_COLOR_ARRAY',0x845E)
GL_SECONDARY_COLOR_ARRAY_POINTER=_C('GL_SECONDARY_COLOR_ARRAY_POINTER',0x845D)
GL_SECONDARY_COLOR_ARRAY_SIZE=_C('GL_SECONDARY_COLOR_ARRAY_SIZE',0x845A)
GL_SECONDARY_COLOR_ARRAY_STRIDE=_C('GL_SECONDARY_COLOR_ARRAY_STRIDE',0x845C)
GL_SECONDARY_COLOR_ARRAY_TYPE=_C('GL_SECONDARY_COLOR_ARRAY_TYPE',0x845B)
GL_TEXTURE_COMPARE_FUNC=_C('GL_TEXTURE_COMPARE_FUNC',0x884D)
GL_TEXTURE_COMPARE_MODE=_C('GL_TEXTURE_COMPARE_MODE',0x884C)
GL_TEXTURE_DEPTH_SIZE=_C('GL_TEXTURE_DEPTH_SIZE',0x884A)
GL_TEXTURE_FILTER_CONTROL=_C('GL_TEXTURE_FILTER_CONTROL',0x8500)
GL_TEXTURE_LOD_BIAS=_C('GL_TEXTURE_LOD_BIAS',0x8501)
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glBlendColor(red,green,blue,alpha):pass
@_f
@_p.types(None,_cs.GLenum)
def glBlendEquation(mode):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLenum,_cs.GLenum)
def glBlendFuncSeparate(sfactorRGB,dfactorRGB,sfactorAlpha,dfactorAlpha):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLsizei,ctypes.c_void_p)
def glFogCoordPointer(type,stride,pointer):pass
@_f
@_p.types(None,_cs.GLdouble)
def glFogCoordd(coord):pass
@_f
@_p.types(None,arrays.GLdoubleArray)
def glFogCoorddv(coord):pass
@_f
@_p.types(None,_cs.GLfloat)
def glFogCoordf(coord):pass
@_f
@_p.types(None,arrays.GLfloatArray)
def glFogCoordfv(coord):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLintArray,arrays.GLsizeiArray,_cs.GLsizei)
def glMultiDrawArrays(mode,first,count,drawcount):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLsizeiArray,_cs.GLenum,arrays.GLvoidpArray,_cs.GLsizei)
def glMultiDrawElements(mode,count,type,indices,drawcount):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLfloat)
def glPointParameterf(pname,param):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLfloatArray)
def glPointParameterfv(pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint)
def glPointParameteri(pname,param):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLintArray)
def glPointParameteriv(pname,params):pass
@_f
@_p.types(None,_cs.GLbyte,_cs.GLbyte,_cs.GLbyte)
def glSecondaryColor3b(red,green,blue):pass
@_f
@_p.types(None,arrays.GLbyteArray)
def glSecondaryColor3bv(v):pass
@_f
@_p.types(None,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble)
def glSecondaryColor3d(red,green,blue):pass
@_f
@_p.types(None,arrays.GLdoubleArray)
def glSecondaryColor3dv(v):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glSecondaryColor3f(red,green,blue):pass
@_f
@_p.types(None,arrays.GLfloatArray)
def glSecondaryColor3fv(v):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint,_cs.GLint)
def glSecondaryColor3i(red,green,blue):pass
@_f
@_p.types(None,arrays.GLintArray)
def glSecondaryColor3iv(v):pass
@_f
@_p.types(None,_cs.GLshort,_cs.GLshort,_cs.GLshort)
def glSecondaryColor3s(red,green,blue):pass
@_f
@_p.types(None,arrays.GLshortArray)
def glSecondaryColor3sv(v):pass
@_f
@_p.types(None,_cs.GLubyte,_cs.GLubyte,_cs.GLubyte)
def glSecondaryColor3ub(red,green,blue):pass
@_f
@_p.types(None,arrays.GLubyteArray)
def glSecondaryColor3ubv(v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLuint)
def glSecondaryColor3ui(red,green,blue):pass
@_f
@_p.types(None,arrays.GLuintArray)
def glSecondaryColor3uiv(v):pass
@_f
@_p.types(None,_cs.GLushort,_cs.GLushort,_cs.GLushort)
def glSecondaryColor3us(red,green,blue):pass
@_f
@_p.types(None,arrays.GLushortArray)
def glSecondaryColor3usv(v):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLenum,_cs.GLsizei,ctypes.c_void_p)
def glSecondaryColorPointer(size,type,stride,pointer):pass
@_f
@_p.types(None,_cs.GLdouble,_cs.GLdouble)
def glWindowPos2d(x,y):pass
@_f
@_p.types(None,arrays.GLdoubleArray)
def glWindowPos2dv(v):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat)
def glWindowPos2f(x,y):pass
@_f
@_p.types(None,arrays.GLfloatArray)
def glWindowPos2fv(v):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint)
def glWindowPos2i(x,y):pass
@_f
@_p.types(None,arrays.GLintArray)
def glWindowPos2iv(v):pass
@_f
@_p.types(None,_cs.GLshort,_cs.GLshort)
def glWindowPos2s(x,y):pass
@_f
@_p.types(None,arrays.GLshortArray)
def glWindowPos2sv(v):pass
@_f
@_p.types(None,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble)
def glWindowPos3d(x,y,z):pass
@_f
@_p.types(None,arrays.GLdoubleArray)
def glWindowPos3dv(v):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glWindowPos3f(x,y,z):pass
@_f
@_p.types(None,arrays.GLfloatArray)
def glWindowPos3fv(v):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint,_cs.GLint)
def glWindowPos3i(x,y,z):pass
@_f
@_p.types(None,arrays.GLintArray)
def glWindowPos3iv(v):pass
@_f
@_p.types(None,_cs.GLshort,_cs.GLshort,_cs.GLshort)
def glWindowPos3s(x,y,z):pass
@_f
@_p.types(None,arrays.GLshortArray)
def glWindowPos3sv(v):pass
